@@ -76,7 +76,7 @@ class Namecheap(syst3m.objects.Object):
 			info = response["domains"][domain]
 			exists = True
 		except: exists = False
-		return r3sponse.success(f"Successfully checked the ownership for domain [{domain}] from namecheap user [{self.username}].", {"exists":exists})
+		return Response.success(f"Successfully checked the ownership for domain [{domain}] from namecheap user [{self.username}].", {"exists":exists})
 
 		#
 	def get_domains(self):
@@ -86,7 +86,7 @@ class Namecheap(syst3m.objects.Object):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to retrieve the domains of namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to retrieve the domains of namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		domains = {}
@@ -102,7 +102,7 @@ class Namecheap(syst3m.objects.Object):
 			else: raise ValueError(f"Unkown domain type: {domain}.")
 
 		# handlers.
-		return r3sponse.success(f"Successfully retrieved the domains of namecheap user [{self.username}].", {
+		return Response.success(f"Successfully retrieved the domains of namecheap user [{self.username}].", {
 			"domains":domains,
 		})
 
@@ -116,23 +116,23 @@ class Namecheap(syst3m.objects.Object):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return Response.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# api request get info.
 		response = self.__request__("namecheap.domains.getInfo", {"DomainName":domain})
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			info = response["api_response"]["command_response"]["domain_get_info_result"]
 		except KeyError:
-			return r3sponse.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}].")
+			return Response.error(f"Failed to retrieve the info of domain [{domain}] from namecheap user [{self.username}].")
 
 		# handlers.
-		return r3sponse.success(f"Successfully retrieved the domain info of namecheap user [{self.username}].", {
+		return Response.success(f"Successfully retrieved the domain info of namecheap user [{self.username}].", {
 			"info":info,
 		})
 
@@ -146,7 +146,7 @@ class Namecheap(syst3m.objects.Object):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return Response.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# api request.
 		response = self.get_sld_and_tld(domain)
@@ -156,13 +156,13 @@ class Namecheap(syst3m.objects.Object):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["domain_dnsget_hosts_result"]
 		except KeyError:
-			return r3sponse.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}].")
+			return Response.error(f"Failed to retrieve the dns info for domain [{domain}] from namecheap user [{self.username}].")
 
 		# iterate data.
 		records = {}
@@ -195,7 +195,7 @@ class Namecheap(syst3m.objects.Object):
 				records[tag] = serialized
 
 		# handlers.
-		return r3sponse.success(f"Successfully retrieved the dns info of namecheap user [{self.username}].", {
+		return Response.success(f"Successfully retrieved the dns info of namecheap user [{self.username}].", {
 			"records":records,
 		})
 
@@ -233,7 +233,7 @@ class Namecheap(syst3m.objects.Object):
 
 		# handlers.
 		exists = tag in list(records.keys())
-		return r3sponse.success(f"Successfully checked dns record [{tag}] of namecheap user [{self.username}].", {
+		return Response.success(f"Successfully checked dns record [{tag}] of namecheap user [{self.username}].", {
 			"exists":exists,
 			"tag":tag,
 		})
@@ -264,7 +264,7 @@ class Namecheap(syst3m.objects.Object):
 		response = self.check_domain(domain)
 		if response.error != None: return response
 		elif not response["exists"]:
-			return r3sponse.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
+			return Response.error(f"Namecheap user [{self.username}] does not own domain [{domain}].")
 
 		# sld & tld.
 		response = self.get_sld_and_tld(domain)
@@ -286,13 +286,13 @@ class Namecheap(syst3m.objects.Object):
 				except KeyError:
 					data[f"TTL{c}"] = 1800
 			except KeyError:
-				return r3sponse.error(f"Invalid usage, each record dictionary must have the following keys: [host, type, value].")
+				return Response.error(f"Invalid usage, each record dictionary must have the following keys: [host, type, value].")
 			c += 1
 		response = self.__request__("namecheap.domains.dns.setHosts", data)
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
@@ -302,9 +302,9 @@ class Namecheap(syst3m.objects.Object):
 
 		# handlers.
 		if success:
-			return r3sponse.success(f"Successfully set dns records for domain [{domain}] from namecheap user [{self.username}].")
+			return Response.success(f"Successfully set dns records for domain [{domain}] from namecheap user [{self.username}].")
 		else:
-			return r3sponse.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}].")
+			return Response.error(f"Failed to set the dns records for domain [{domain}] from namecheap user [{self.username}].")
 
 		#
 	def add_dns(self,
@@ -342,7 +342,7 @@ class Namecheap(syst3m.objects.Object):
 		# handle exact duplicate.
 		elif response["exists"]:
 			tag = response["tag"]
-			return r3sponse.error(f"DNS record [{tag}] from namecheap domain [{domain}] already exists.")
+			return Response.error(f"DNS record [{tag}] from namecheap domain [{domain}] already exists.")
 
 		# add new.
 		else:
@@ -362,7 +362,7 @@ class Namecheap(syst3m.objects.Object):
 			if response.error != None: return response
 
 			# success.
-			return r3sponse.success(f"Successfully added dns record [{tag}] to namecheap domain [{domain}].", {"tag":tag})
+			return Response.success(f"Successfully added dns record [{tag}] to namecheap domain [{domain}].", {"tag":tag})
 
 		#
 	def tag_dns(self,
@@ -374,7 +374,7 @@ class Namecheap(syst3m.objects.Object):
 		value=None,
 	):
 		tag = f"{type}|{host}|{value}"
-		return r3sponse.success(f"Successfully taggeed dns record [{tag}].", {"tag":tag})
+		return Response.success(f"Successfully taggeed dns record [{tag}].", {"tag":tag})
 	def get_sld_and_tld(self, domain=None):
 
 		# set default domain.
@@ -395,7 +395,7 @@ class Namecheap(syst3m.objects.Object):
 			c += 1
 
 		# handlers.
-		return r3sponse.success(f"Successfully retrieded the SLD & TLD of domain [{domain}].", {
+		return Response.success(f"Successfully retrieded the SLD & TLD of domain [{domain}].", {
 			"tld":tld,
 			"sld":sld,
 		})
@@ -408,13 +408,13 @@ class Namecheap(syst3m.objects.Object):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to retrieve the tls list from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["ssllist_result"]
 		except KeyError:
-			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
+			return Response.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
 
 		# iterate data.
 		tls = {}
@@ -428,7 +428,7 @@ class Namecheap(syst3m.objects.Object):
 				tls[_data_["certificate_id"]] = _data_
 
 		# handlers.
-		return r3sponse.success(f"Successfully retrieved the tls list for namecheap user [{self.username}].", {
+		return Response.success(f"Successfully retrieved the tls list for namecheap user [{self.username}].", {
 			"tls":tls,
 			"certificates":len(tls),
 		})
@@ -449,17 +449,17 @@ class Namecheap(syst3m.objects.Object):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to create tls certificate from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to create tls certificate from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["sslcreate_result"]
 		except KeyError:
-			return r3sponse.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
+			return Response.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
 
 		# handlers.
 		if data["is_success"]:
-			return r3sponse.success(f"Successfully created a tls certificate for namecheap user [{self.username}].", {
+			return Response.success(f"Successfully created a tls certificate for namecheap user [{self.username}].", {
 				"certificate_id":data["sslcertificate"]["certificate_id"],
 				"order_id":data["order_id"],
 				"transaction_id":data["transaction_id"],
@@ -469,7 +469,7 @@ class Namecheap(syst3m.objects.Object):
 				"years":data["sslcertificate"]["years"],
 			})
 		else:
-			return r3sponse.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
+			return Response.error(f"Failed to create a tls certificate for namecheap user [{self.username}].")
 
 		#
 	def activate_tls(self,
@@ -480,7 +480,7 @@ class Namecheap(syst3m.objects.Object):
 		# check csr.
 		csr = f"{self.database}/tls/server.csr"
 		if not Files.exists(csr):
-			return r3sponse.error(f"There is no tls certificate present.")
+			return Response.error(f"There is no tls certificate present.")
 		csr = Files.load(csr)
 
 		# api request.
@@ -493,17 +493,17 @@ class Namecheap(syst3m.objects.Object):
 		if response["api_response"]["errors"] != None: 
 			try: error = response["api_response"]["errors"]["error"]["#text"]
 			except KeyError: error = response["api_response"]["errors"]
-			return r3sponse.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}], error: {error}")
+			return Response.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}], error: {error}")
 
 		# handle response.
 		try:
 			data = response["api_response"]["command_response"]["sslactivate_result"]
 		except KeyError:
-			return r3sponse.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
+			return Response.error(f"Failed to retrieve the tls list from namecheap user [{self.username}].")
 
 		# handlers.
 		if not data["is_success"]:
-			return r3sponse.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}].")
+			return Response.error(f"Failed to activate tls certificate [{certificate_id}] from namecheap user [{self.username}].")
 
 		# add dns validation record. 
 		dns_validation = data["dnsdcvalidation"]["dns"]
@@ -521,7 +521,7 @@ class Namecheap(syst3m.objects.Object):
 		if response.error != None and "] already exists." not in response.error: return response
 		
 		# handlers.
-		return r3sponse.success(f"Successfully activated tls certificate [{certificate_id}] from namecheap user [{self.username}].")
+		return Response.success(f"Successfully activated tls certificate [{certificate_id}] from namecheap user [{self.username}].")
 
 		#
 	# system functions.
